==> cfn_lint-1.2.5a10.tar.gz: cfn_lint-1.2.5a10/test/unit/rules/resources/ecs/test_task_definition_essentials.py <==
"""
Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""

from collections import deque

import pytest

from cfnlint.jsonschema import CfnTemplateValidator, ValidationError
from cfnlint.rules.resources.ecs.TaskDefinitionEssentialContainer import (
    TaskDefinitionEssentialContainer,
)


@pytest.fixture(scope="module")
def rule():
    rule = TaskDefinitionEssentialContainer()
    yield rule


@pytest.fixture(scope="module")
def validator():
    yield CfnTemplateValidator(schema={})


@pytest.mark.parametrize(
    "instance,expected",
    [
        (
            [{"Essential": True}],
            [],
        ),
        (
            [{"Essential": True}, {"Essential": False}],
            [],
        ),
        (
            {},  # wrong type
            [],
        ),
        (
            [{"Essential": {"Ref": "Essential"}}, {"Essential": False}],
            [],
        ),
        (
            [{"Essential": False}],
            [
                ValidationError(
                    "At least one essential container is required",
                    rule=TaskDefinitionEssentialContainer(),
                    path=deque([]),
                    validator="contains",
                    schema_path=deque(["contains"]),
                )
            ],
        ),
        (
            [],
            [
                ValidationError(
                    "At least one essential container is required",
                    rule=TaskDefinitionEssentialContainer(),
                    path=deque([]),
                    validator="minItems",
                    schema_path=deque(["minItems"]),
                )
            ],
        ),
    ],
)
def test_validate(instance, expected, rule, validator):
    errs = list(rule.validate(validator, "", instance, {}))

    assert errs == expected, f"Expected {expected} got {errs}"

==> cfn_lint-1.3.4.tar.gz: cfn_lint-1.3.4/test/unit/rules/resources/ecs/test_task_definition_essentials.py <==
"""
Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""

from collections import deque

import pytest

from cfnlint.jsonschema import ValidationError
from cfnlint.rules.resources.ecs.TaskDefinitionEssentialContainer import (
    TaskDefinitionEssentialContainer,
)


@pytest.fixture(scope="module")
def rule():
    rule = TaskDefinitionEssentialContainer()
    yield rule


@pytest.mark.parametrize(
    "instance,expected",
    [
        (
            [{"Essential": True}],
            [],
        ),
        (
            [{"Essential": True}, {"Essential": False}],
            [],
        ),
        (
            {},  # wrong type
            [],
        ),
        (
            [{"Essential": {"Ref": "Essential"}}, {"Essential": False}],
            [],
        ),
        (
            [{"Essential": False}],
            [
                ValidationError(
                    "At least one essential container is required",
                    rule=TaskDefinitionEssentialContainer(),
                    path=deque([]),
                    validator="contains",
                    schema_path=deque(["contains"]),
                )
            ],
        ),
        (
            [],
            [
                ValidationError(
                    "At least one essential container is required",
                    rule=TaskDefinitionEssentialContainer(),
                    path=deque([]),
                    validator="minItems",
                    schema_path=deque(["minItems"]),
                )
            ],
        ),
    ],
)
def test_validate(instance, expected, rule, validator):
    errs = list(rule.validate(validator, "", instance, {}))

    assert errs == expected, f"Expected {expected} got {errs}"
